[PATCH 5/7] user32: Change slave to a more neutral word

André Hentschel nerv at dawncrow.de
Tue Jun 16 08:35:31 CDT 2020


Signed-off-by: André Hentschel <nerv at dawncrow.de>
---
 dlls/user32/sysparams.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/dlls/user32/sysparams.c b/dlls/user32/sysparams.c
index 82ed8513646..3094251cca9 100644
--- a/dlls/user32/sysparams.c
+++ b/dlls/user32/sysparams.c
@@ -3910,7 +3910,7 @@ static BOOL update_monitor_cache(void)
     HANDLE mutex = NULL;
     DWORD state_flags;
     BOOL ret = FALSE;
-    BOOL mirrored_slave;
+    BOOL mirrored_secondary;
     DWORD i = 0, j;
     DWORD type;
 
@@ -3956,17 +3956,17 @@ static BOOL update_monitor_cache(void)
                                         (BYTE *)&monitors[monitor_count].rcMonitor, sizeof(RECT), NULL, 0 ))
             goto fail;
 
-        /* Mirrored slave monitors also don't get enumerated */
-        mirrored_slave = FALSE;
+        /* Mirrored secondary monitors also don't get enumerated */
+        mirrored_secondary = FALSE;
         for (j = 0; j < monitor_count; j++)
         {
             if (EqualRect(&monitors[j].rcMonitor, &monitors[monitor_count].rcMonitor))
             {
-                mirrored_slave = TRUE;
+                mirrored_secondary = TRUE;
                 break;
             }
         }
-        if (mirrored_slave)
+        if (mirrored_secondary)
             continue;
 
         if (!SetupDiGetDevicePropertyW( devinfo, &device_data, &WINE_DEVPROPKEY_MONITOR_RCWORK, &type,
-- 
2.17.1




More information about the wine-devel mailing list